@@ -189,6 +189,4 @@ response = api.request("nasa", variables=variables)
 
 # Print API Response
 print(response)
-'''
-load('/Users/addie/Downloads/noapicode.json')
-print(request('nasa', {'apiKey':'DEMO_KEY'}))
\ No newline at end of file
+'''
\ No newline at end of file
